@@ -33,6 +33,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_iam
@@ -64,6 +66,10 @@ class ManagedInstanceRole(
         :param retention_policy: The retention policy for this role.
         :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ManagedInstanceRole.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ManagedInstanceRoleProps(
             create_instance_profile=create_instance_profile,
             domain_join_enabled=domain_join_enabled,
@@ -127,6 +133,13 @@ class ManagedInstanceRoleProps:
         :param retention_policy: The retention policy for this role.
         :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ManagedInstanceRoleProps.__init__)
+            check_type(argname="argument create_instance_profile", value=create_instance_profile, expected_type=type_hints["create_instance_profile"])
+            check_type(argname="argument domain_join_enabled", value=domain_join_enabled, expected_type=type_hints["domain_join_enabled"])
+            check_type(argname="argument managed_policies", value=managed_policies, expected_type=type_hints["managed_policies"])
+            check_type(argname="argument retention_policy", value=retention_policy, expected_type=type_hints["retention_policy"])
+            check_type(argname="argument ssm_management_enabled", value=ssm_management_enabled, expected_type=type_hints["ssm_management_enabled"])
         self._values: typing.Dict[str, typing.Any] = {}
         if create_instance_profile is not None:
             self._values["create_instance_profile"] = create_instance_profile
